@@ -22,7 +22,7 @@
  */
 
 class SyslogPostgreSQLParser extends PostgreSQLParser {
-	var $regexpPostgresPid;
+	var $regexpSyslogContext;
 	
 	function SyslogPostgreSQLParser($syslogString = 'postgres') {
 		$this->regexpSyslogContext = new RegExp('/^([A-Z][a-z]{2} [ 0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}) .*? '.$syslogString.'\[(\d{1,5})\]: \[(\d{1,20})(?:\-(\d{1,5}))?\] /');
@@ -31,14 +31,16 @@ class SyslogPostgreSQLParser extends PostgreSQLParser {
 	function & parse($data) {
 		$syslogContextMatch =& $this->regexpSyslogContext->match($data);
 		if($syslogContextMatch === false) {
-			return false;
+			$line = false;
+			return $line;
 		}
 		
 		$matches = $syslogContextMatch->getMatches();
 		$text = $syslogContextMatch->getPostMatch();
 		
 		if(count($matches) < 4 || !$text) {
-			return false;
+			$line = false;
+			return $line;
 		}
 		
 		$formattedDate = $matches[1][0];
@@ -64,10 +66,6 @@ class SyslogPostgreSQLParser extends PostgreSQLParser {
 		
 		if($line) {
 			$line->setContextInformation($timestamp, $connectionId, $commandNumber, $lineNumber);
-		
-			if(CONFIG_TIMESTAMP_FILTER && ($timestamp < CONFIG_FROM_TIMESTAMP || $timestamp > CONFIG_TO_TIMESTAMP)) {
-				$line = false;
-			}
 		}
 		return $line;
 	}
