@@ -22,13 +22,13 @@
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-define('VERSION', '0.5');
+define('VERSION', '0.5.99');
 
 ini_set('max_execution_time', 18000);
 ini_set('memory_limit', '128M');
 
 if(strpos(phpversion(), '4.4') === 0) {
-	error_reporting(E_ALL && !E_NOTICE);
+	error_reporting(E_ALL - E_NOTICE);
 } else {
 	error_reporting(E_ALL);
 }
@@ -51,7 +51,8 @@ function usage($error = false) {
   -                                      read the log from stdin instead of -file
   -top <n>                               number of queries in lists. Default is 20.
   -format <format>                       output format: html, html-with-graphs or text. Default is html.
-  -logtype <logtype>                     log type: only syslog is currently supported
+  -logtype <logtype>                     log type: syslog or stderr. Default is stderr.
+                                          for stderr, you have to use the following log_line_prefix: \'%t [%p]: [%l-1] \'
   -report [outputfile=]<block1,block2>   list of report blocks separated by a comma
                                          report blocks can be: overall, hourly, bytype, slowest, n-mosttime,
                                           n-mostfrequent, n-slowestaverage, n-mostfrequenterrors
@@ -60,6 +61,9 @@ function usage($error = false) {
   -onlyselect                            ignore all queries but SELECT
   -from "<date>"                         ignore lines logged before this date (uses strtotime)
   -to "<date>"                           ignore lines logged after this date (uses strtotime)
+  -database <database>                   consider only queries on this database
+  -user <user>                           consider only queries executed by this user
+  -title <title>                         define the title of the reports
   -debug                                 debug mode
   -profile                               profile mode
   -help                                  this help
@@ -157,6 +161,12 @@ if(!CONFIG_STDIN) {
 	$filePath = 'php://stdin';
 }
 
+if(isset($options['title'])) {
+	define('CONFIG_REPORT_TITLE', $options['title']);
+} else {
+	define('CONFIG_REPORT_TITLE', 'pgFouine: PostgreSQL log analysis report');
+}
+
 if(isset($options['top'])) {
 	if((int) $options['top'] > 0) {
 		$top = (int) $options['top'];
@@ -231,7 +241,7 @@ if(isset($options['format'])) {
 	$aggregator = $supportedFormats['html'];
 }
 
-$supportedLogTypes = array('syslog' => 'SyslogPostgreSQLParser');
+$supportedLogTypes = array('syslog' => 'SyslogPostgreSQLParser', 'stderr' => 'StderrPostgreSQLParser');
 if(isset($options['logtype'])) {
 	if(array_key_exists($options['logtype'], $supportedLogTypes)) {
 		$parser = $supportedLogTypes[$options['logtype']];
@@ -255,6 +265,18 @@ if(isset($options['onlyselect'])) {
 	define('CONFIG_ONLY_SELECT', false);
 }
 
+if(isset($options['database']) && !empty($options['database'])) {
+	define('CONFIG_DATABASE', $options['database']);
+} else {
+	define('CONFIG_DATABASE', false);
+}
+
+if(isset($options['user']) && !empty($options['user'])) {
+	define('CONFIG_USER', $options['user']);
+} else {
+	define('CONFIG_USER', false);
+}
+
 if(isset($options['from']) && !empty($options['from'])) {
 	$fromTimestamp = strtotime($options['to']);
 	if($fromTimestamp <= 0) {
